@@ -14,7 +14,7 @@ from chromadb.api.types import IncludeEnum
 
 from vectorcode.chunking import FileChunker
 from vectorcode.cli_utils import Config, expand_globs, expand_path
-from vectorcode.common import get_client, make_or_get_collection, verify_ef
+from vectorcode.common import get_client, get_collection, verify_ef
 
 
 def hash_str(string: str) -> str:
@@ -84,7 +84,7 @@ def show_stats(configs: Config, stats):
 async def vectorise(configs: Config) -> int:
     client = await get_client(configs)
     try:
-        collection = await make_or_get_collection(client, configs)
+        collection = await get_collection(client, configs, True)
     except IndexError:
         print("Failed to get/create the collection. Please check your config.")
         return 1
@@ -133,13 +133,18 @@ async def vectorise(configs: Config) -> int:
             print("Abort.", file=sys.stderr)
             return 1
 
-    all_results = await collection.get(include=[IncludeEnum.metadatas])
-    if all_results is not None and all_results.get("metadatas"):
-        for idx in range(len(all_results["ids"])):
-            path_in_meta = str(all_results["metadatas"][idx].get("path"))
-            if path_in_meta is not None and not os.path.isfile(path_in_meta):
-                await collection.delete(where={"path": path_in_meta})
-                stats["removed"] += 1
+    async with collection_lock:
+        all_results = await collection.get(include=[IncludeEnum.metadatas])
+        if all_results is not None and all_results.get("metadatas"):
+            paths = (meta["path"] for meta in all_results["metadatas"])
+            orphanes = set()
+            for path in paths:
+                if isinstance(path, str) and not os.path.isfile(path):
+                    orphanes.add(path)
+            async with stats_lock:
+                stats["removed"] = len(orphanes)
+            if len(orphanes):
+                await collection.delete(where={"path": {"$in": list(orphanes)}})
 
     show_stats(configs=configs, stats=stats)
     return 0
